##  Reporting a Mistake in Fact Sheet Metadata
If you notice a mistake in fact sheet metadata, you can report it to our research team for investigation and resolution. Here’s how you can report a mistake for different data types:
  * Business capabilities, applications, and tech categories (including linked providers): [Submit a ticket![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") to SAP LeanIX Support. If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
  * IT components: You can report a mistake in fact sheet metadata from the reference catalog page (for multiple items) or the fact sheet linking page (for a single item) using the Report Missing Data option. For detailed information, see [Report Missing Data in Catalog Items](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD#loio275adf737a44101482dccd5ff2ab307e__report_missing_data_in_catalog_items).
